@@ -14,11 +14,8 @@
 # limitations under the License.
 """Generic flags that apply to multiple commands."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import enum
+import textwrap
 
 from googlecloudsdk.api_lib.storage import cloud_api
 from googlecloudsdk.calliope import actions
@@ -60,6 +57,45 @@ For more information about supported configurations, see
 [Cloud Storage bucket IP filtering configurations](https://cloud.google.com/storage/docs/create-ip-filter#ip-filtering-configurations)
 """
 
+_ENCRYPTION_ENFORCEMENT_HELP_TEXT = textwrap.dedent("""\
+Sets the encryption enforcement configuration for the bucket from a JSON file.
+This configuration determines restrictions on the types of encryption (GMEK,
+CMEK, CSEK) allowed for new objects created in the bucket.
+
+The JSON file should contain an object with keys among "gmekEnforcement",
+"cmekEnforcement", and "csekEnforcement". Each of these keys, if present,
+should have a "restrictionMode" key, determining whether the corresponding
+encryption type should be allowed or restricted for new objects.
+
+Valid values for "restrictionMode" are:
+- "NotRestricted": The encryption type is allowed for new objects.
+- "FullyRestricted": The encryption type is not allowed for new objects.
+
+Example JSON file content, to enforce only CMEK for new objects:
+
+  {
+    "gmekEnforcement": {
+      "restrictionMode": "FullyRestricted"
+    },
+    "cmekEnforcement": {
+      "restrictionMode": "NotRestricted"
+    },
+    "csekEnforcement": {
+      "restrictionMode": "FullyRestricted"
+    }
+  }
+
+Omitted keys will not be sent in the API request. To clear restrictions for a
+specific encryption-type during an update, set its "restrictionMode" to
+"NotRestricted".
+For example, to clear any restrictions on GMEK:
+  {
+    "gmekEnforcement": {
+      "restrictionMode": "NotRestricted"
+    }
+  }
+""")
+
 _CUSTOM_CONTEXT_FILE_HELP_TEXT = """
 Path to a local JSON or YAML file containing custom contexts one wants to set on
 an object. For example:
@@ -144,7 +180,6 @@ def get_object_context_group(parser):
       help=(
           'Group that allow users to handle object contexts.'
       ),
-      hidden=True,
   )
 
 
@@ -159,10 +194,12 @@ def add_object_contexts_flags(parser):
   )
   context_subgroup = context_group.add_group(
       help=(
-          'Flags that preserves the existing contexts on the object, and can be'
+          'Flags that preserve the existing contexts on the object, and can be'
           ' specified together. However they cannot be specified with'
           ' `--clear-custom-contexts`, `--custom-contexts` or'
-          ' `--custom-contexts-file`.'
+          ' `--custom-contexts-file`. If `--update-custom-contexts` and'
+          ' `--remove-custom-contexts` are specified together, the'
+          ' `--remove-custom-contexts` would be applied first on object.'
       ),
   )
   context_subgroup.add_argument(
@@ -490,6 +527,19 @@ def add_encryption_flags(parser,
              ' if one exists, or else with a Google-managed encryption key.')
 
 
+def add_encryption_enforcement_file_flag(parser):
+  """Adds the --encryption-enforcement-file flag for buckets commands.
+
+  Args:
+    parser (parser_arguments.ArgumentInterceptor): Parser passed to surface.
+  """
+  parser.add_argument(
+      '--encryption-enforcement-file',
+      help=_ENCRYPTION_ENFORCEMENT_HELP_TEXT,
+      hidden=True,
+  )
+
+
 def add_continue_on_error_flag(parser):
   """Adds flag to indicate error should be skipped instead of being raised."""
   parser.add_argument(
@@ -634,12 +684,15 @@ def add_dataset_config_location_flag(parser, is_required=True):
   )
 
 
-def add_dataset_config_create_update_flags(parser, is_update=False):
+def add_dataset_config_create_update_flags(
+    parser, is_update=False, release_track=base.ReleaseTrack.GA
+):
   """Adds the flags for the dataset-config create and update commands.
 
   Args:
     parser (parser_arguments.ArgumentInterceptor): Parser passed to surface.
     is_update (bool): True if flags are for the dataset-configs update command.
+    release_track (base.ReleaseTrack): The release track of command.
   """
   parser.add_argument(
       '--retention-period-days',
@@ -648,6 +701,20 @@ def add_dataset_config_create_update_flags(parser, is_update=False):
       required=not is_update,
       help='Provide retention period for the config.',
   )
+
+  if release_track == base.ReleaseTrack.ALPHA:
+    parser.add_argument(
+        '--activity-data-retention-period-days',
+        type=int,
+        metavar='ACTIVITY_DATA_RETENTION_DAYS',
+        required=False,
+        help=(
+            'Provide retention period for the activity data in the config. This'
+            ' overrides the retention period for activity data. Otherwise, the'
+            ' `retention_period_days` value is used for activity data as well.'
+        ),
+    )
+
   parser.add_argument(
       '--description',
       type=str,
@@ -888,18 +955,19 @@ def add_soft_deleted_flag(parser, hidden=False):
   )
 
 
-def add_server_filter_flag(parser):
+def add_metadata_filter_flag(parser):
   """Adds flag for filtering objects by server side filtering."""
   parser.add_argument(
-      '--server-filter',
+      '--metadata-filter',
       type=str,
-      hidden=True,
       help=(
-          'Server side filtering for objects, Works only for Google Cloud'
+          'Server side filtering for objects. Works only for Google Cloud'
           ' Storage URLs. The filter only works for objects, and not'
-          ' directories or buckets. which means commands like `storage ls` and'
+          ' directories or buckets, which means commands like `storage ls` and'
           ' `storage du` will still list directories or buckets even if they do'
-          ' not contain any objects matching the filter.'
+          ' not contain any objects matching the filter. See'
+          ' https://cloud.google.com/storage/docs/listing-objects#filter-by-object-contexts-syntax'
+          ' for more details.'
       ),
   )
 
@@ -1368,13 +1436,16 @@ def add_batch_jobs_flags(parser):
           ' `Content-Type={VALUE}`. To set how caches should handle requests'
           ' and responses, specify the key-value pair `Cache-Control={VALUE}`.'
           ' To set custom time for Cloud Storage objects in RFC 3339 format,'
-          ' specify the key-value pair `Custom-Time={VALUE}`. To set custom'
-          ' metadata on objects, specify key-value pairs'
-          ' `{CUSTOM-KEY}:{VALUE}`. Note that all predefined keys (e.g.'
+          ' specify the key-value pair `Custom-Time={VALUE}`. To set object'
+          ' retention, specify `Retain-Until={TIMESTAMP}` in RFC 3339 format'
+          ' and `Retention-Mode={MODE}` where mode can be `Locked` or'
+          ' `Unlocked`. To set custom metadata on objects, specify key-value'
+          ' pairs `{CUSTOM-KEY}:{VALUE}`. Note that all predefined keys (e.g.'
           ' Content-Disposition) are case-insensitive. Any other key that is'
-          ' not specified above will be treated as a custom key. Multiple'
-          ' key-value pairs can be specified by separating them with commas.'
-          ' For example,'
+          ' not specified above will be treated as a custom key. To clear a'
+          ' field, provide the key with an empty value (e.g.'
+          ' `Content-Disposition=`). Multiple key-value pairs can be specified'
+          ' by separating them with commas. For example,'
           ' `--put-metadata=Content-Disposition=inline,Content-Encoding=gzip`'
       ),
       type=arg_parsers.ArgDict(min_length=1),
